package org.example;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;

public class AllOfErrorHandlingExample {
    public static void main(String[] args) {
        CompletableFuture<Integer> future1 = CompletableFuture.supplyAsync(() -> 5)
                .exceptionally(ex -> {
                    System.err.println("Exception in future1: " + ex);
                    return 0; // Default value or recovery logic
                });

        CompletableFuture<Object> future2 = CompletableFuture.supplyAsync(() -> {
            throw new RuntimeException("Something went wrong");
        }).exceptionally(ex -> {
            System.err.println("Exception in future2: " + ex);
            return 0; // Default value or recovery logic
        });

        CompletableFuture<Void> combinedFuture = CompletableFuture.allOf(future1, future2);
        combinedFuture.join();

        try {
            int result1 = future1.get();
            int result2 = (int) future2.get();
            System.out.println("Result 1: " + result1);
            System.out.println("Result 2: " + result2);
        } catch (InterruptedException | ExecutionException e) {
            e.printStackTrace();
        }
    }
}